Skip to main content

Vasara

A fun little command-line tool for fetching random Warhammer lore snippets from the wikis.

Usage

vasara is a command-line tool for fetching random Warhammer lore snippets.

vasara [universe] [OPTIONS]

Arguments:

  • universe: The Warhammer universe you want to get lore snippets from.
    • Choices: 40k, fantasy, aos
    • Default: 40k

Options:

  • -c, --count <COUNT>: Number of lore snippets to fetch.
    • Default: 1
  • -p, --paragraph: Fetch a full paragraph instead of a snippet.
  • -m, --max-length <MAX_LENGTH>: Maximum length of the snippets.
    • Default: 190
  • -f, --format <FORMAT>: Output format.
    • Choices: text, json
    • Default: text
  • --retries <RETRIES>: Number of retries to attempt before cancelling.
    • Default: 5
  • --max-workers <RETRIES>: Max number of worker threads used for concurrently querying the wiki.
    • Default: 500

Examples

Fetch a single Warhammer 40,000 lore snippet (default):

vasara

Fetch 3 Age of Sigmar lore snippets:

vasara aos --count 3

Fetch a full paragraph of Warhammer Fantasy Battles lore:

vasara fantasy --paragraph

Fetch lore in JSON format:

vasara 40k --count 2 --format json

Metadata

Release files for vasara 0.2.0

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for vasara 0.2.0
File Size Uploaded
vasara-0.2.0.tar.gz 15.2 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for vasara 0.2.0
File Interpreter ABI Platform
vasara-0.2.0-py3-none-any.whl Python 3 none any Details

Total release size: 31.8 kB

Release files / vasara-0.2.0.tar.gz

Download URL vasara-0.2.0.tar.gz
Size 15.2 kB
Tags Source
SHA-256 checksum
How to use checksums
c0f1f764ffcf424fcb28e6f522f2d5ff4c21fa50c0873336840b0068a1bab6c2
BLAKE2b-256 checksum
How to use checksums
d07a2ff6fde96af6967ca031fa8aeff167efda280db7000ba83602a171fe8fb3
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via poetry/2.0.1 CPython/3.12.3 Linux/6.11.0-1018-azure

Release files / vasara-0.2.0-py3-none-any.whl

Download URL vasara-0.2.0-py3-none-any.whl
Size 16.6 kB
Tags Python 3
SHA-256 checksum
How to use checksums
8b894d74a4bcd9c0a4772a4ba53c36127b8b93d16e2dbb4d7e209e04a8ddc853
BLAKE2b-256 checksum
How to use checksums
9961ea551dfec2b7d28074452fad0c1d0f55da7b7300a072e1db1168a801dcb4
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via poetry/2.0.1 CPython/3.12.3 Linux/6.11.0-1018-azure

Release history Release notifications | RSS feed

This release

0.2.0 This release

2 release files

0.1.0

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page